==> haskell-th-orphans-0.13.16-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-orphans
version:              0.13.16
visibility:           public
id:                   th-orphans-0.13.16-5wrGkfukqLf8zcC8F1wFvm
key:                  th-orphans-0.13.16-5wrGkfukqLf8zcC8F1wFvm
license:              BSD-3-Clause
copyright:            (c) Matt Morrow, Michael Sloan, Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Matt Morrow, Michael Sloan, Ryan Scott
stability:            experimental
synopsis:             Orphan instances for TH datatypes
description:
    Orphan instances for TH datatypes.  In particular, instances
    for Ord and Lift, as well as a few missing Show / Eq.  These
    instances used to live in haskell-src-meta, and that'\''s where
    the version number started.

category:             Template Haskell
abi:                  dcc634676c87ac74d2f1862f1993f857
exposed:              True
exposed-modules:      Language.Haskell.TH.Instances
hidden-modules:       Language.Haskell.TH.Instances.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/th-orphans-0.13.16
library-dirs:         /usr/lib/ghc-9.4.8/site-local/th-orphans-0.13.16
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/th-orphans-0.13.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-orphans
hs-libraries:         HSth-orphans-0.13.16-5wrGkfukqLf8zcC8F1wFvm
depends:
    base-4.17.2.1 mtl-2.2.2 template-haskell-2.19.0.0
    th-compat-0.1.6-2tF3dEMrKvwirFINizwHu
    th-lift-0.8.5-3bCWMcLwp8dEXoRnv4Yrhx
    th-reify-many-0.1.10-ED5jH7Zh2HPBjUNOnNW7PV

haddock-interfaces:   /usr/share/doc/haskell-th-orphans/html/th-orphans.haddock
haddock-html:         /usr/share/doc/haskell-th-orphans/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-orphans-0.13.16-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-orphans
version:              0.13.16
visibility:           public
id:                   th-orphans-0.13.16-8hVSqd34zY98EFRburFN8V
key:                  th-orphans-0.13.16-8hVSqd34zY98EFRburFN8V
license:              BSD-3-Clause
copyright:            (c) Matt Morrow, Michael Sloan, Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Matt Morrow, Michael Sloan, Ryan Scott
stability:            experimental
synopsis:             Orphan instances for TH datatypes
description:
    Orphan instances for TH datatypes.  In particular, instances
    for Ord and Lift, as well as a few missing Show / Eq.  These
    instances used to live in haskell-src-meta, and that'\''s where
    the version number started.

category:             Template Haskell
abi:                  49952f2935dc4ab0475e4addef8685fa
exposed:              True
exposed-modules:      Language.Haskell.TH.Instances
hidden-modules:       Language.Haskell.TH.Instances.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/th-orphans-0.13.16
library-dirs:         /usr/lib/ghc-9.4.8/site-local/th-orphans-0.13.16
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/th-orphans-0.13.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-orphans
hs-libraries:         HSth-orphans-0.13.16-8hVSqd34zY98EFRburFN8V
depends:
    base-4.17.2.1 mtl-2.2.2 template-haskell-2.19.0.0
    th-compat-0.1.6-1jufj3sSjvQLQAnww3qayU
    th-lift-0.8.5-3bCWMcLwp8dEXoRnv4Yrhx
    th-reify-many-0.1.10-C5TSBorsHdF1m7G3Ra5cNK

haddock-interfaces:   /usr/share/doc/haskell-th-orphans/html/th-orphans.haddock
haddock-html:         /usr/share/doc/haskell-th-orphans/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
